@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2023 by Sukchan Lee <acetcom@gmail.com>
+ * Copyright (C) 2019-2025 by Sukchan Lee <acetcom@gmail.com>
  *
  * This file is part of Open5GS.
  *
@@ -19,7 +19,7 @@
 
 #include "pfcp-path.h"
 
-static void pfcp_node_fsm_init(ogs_pfcp_node_t *node, bool try_to_assoicate)
+static void pfcp_node_fsm_init(ogs_pfcp_node_t *node, bool try_to_associate)
 {
     sgwc_event_t e;
 
@@ -28,7 +28,7 @@ static void pfcp_node_fsm_init(ogs_pfcp_node_t *node, bool try_to_assoicate)
     memset(&e, 0, sizeof(e));
     e.pfcp_node = node;
 
-    if (try_to_assoicate == true) {
+    if (try_to_associate == true) {
         node->t_association = ogs_timer_add(ogs_app()->timer_mgr,
                 sgwc_timer_pfcp_association, node);
         ogs_assert(node->t_association);
@@ -56,50 +56,20 @@ static void pfcp_recv_cb(short when, ogs_socket_t fd, void *data)
 {
     int rv;
 
-    ssize_t size;
     sgwc_event_t *e = NULL;
     ogs_pkbuf_t *pkbuf = NULL;
     ogs_sockaddr_t from;
     ogs_pfcp_node_t *node = NULL;
     ogs_pfcp_message_t *message = NULL;
-    ogs_pfcp_header_t *h = NULL;
 
     ogs_pfcp_status_e pfcp_status;;
     ogs_pfcp_node_id_t node_id;
 
     ogs_assert(fd != INVALID_SOCKET);
 
-    pkbuf = ogs_pkbuf_alloc(NULL, OGS_MAX_SDU_LEN);
-    ogs_assert(pkbuf);
-    ogs_pkbuf_put(pkbuf, OGS_MAX_SDU_LEN);
-
-    size = ogs_recvfrom(fd, pkbuf->data, pkbuf->len, 0, &from);
-    if (size <= 0) {
-        ogs_log_message(OGS_LOG_ERROR, ogs_socket_errno,
-                "ogs_recvfrom() failed");
-        ogs_pkbuf_free(pkbuf);
-        return;
-    }
-
-    ogs_pkbuf_trim(pkbuf, size);
-
-    h = (ogs_pfcp_header_t *)pkbuf->data;
-    if (h->version != OGS_PFCP_VERSION) {
-        ogs_pfcp_header_t rsp;
-
-        ogs_error("Not supported version[%d]", h->version);
-
-        memset(&rsp, 0, sizeof rsp);
-        rsp.flags = (OGS_PFCP_VERSION << 5);
-        rsp.type = OGS_PFCP_VERSION_NOT_SUPPORTED_RESPONSE_TYPE;
-        rsp.length = htobe16(4);
-        rsp.sqn_only = h->sqn_only;
-        if (ogs_sendto(fd, &rsp, 8, 0, &from) < 0) {
-            ogs_log_message(OGS_LOG_ERROR, ogs_socket_errno,
-                    "ogs_sendto() failed");
-        }
-        ogs_pkbuf_free(pkbuf);
-
+    pkbuf = ogs_pfcp_recvfrom(fd, &from);
+    if (!pkbuf) {
+        ogs_error("ogs_pfcp_recvfrom() failed");
         return;
     }
 
@@ -324,6 +294,10 @@ int sgwc_pfcp_send_bearer_to_modify_list(
     ogs_assert(xact);
 
     xact->local_seid = sess->sgwc_sxa_seid;
+    ogs_info("PFCP Session Modification xact: "
+            "sess_id=%d xact=%p local_seid=0x%llx bearer_to_modify_count=%d",
+            sess->id, xact, (unsigned long long)xact->local_seid,
+            ogs_list_count(&xact->bearer_to_modify_list));
 
     memset(&h, 0, sizeof(ogs_pfcp_header_t));
     h.type = OGS_PFCP_SESSION_MODIFICATION_REQUEST_TYPE;
@@ -436,6 +410,10 @@ int sgwc_pfcp_send_session_modification_request(
     sgwc_bearer_t *bearer = NULL;
 
     ogs_assert(sess);
+    ogs_assert(ogs_list_count(&sess->bearer_list));
+    ogs_info("PFCP Session Modification from session: "
+            "sess_id=%d gtp_xact_id=%d flags=0x%llx",
+            sess->id, gtp_xact_id, (unsigned long long)flags);
 
     xact = ogs_pfcp_xact_local_create(
             sess->pfcp_node, sess_timeout, OGS_UINT_TO_POINTER(sess->id));
@@ -474,6 +452,9 @@ int sgwc_pfcp_send_bearer_modification_request(
     ogs_assert(bearer);
     sess = sgwc_sess_find_by_id(bearer->sess_id);
     ogs_assert(sess);
+    ogs_info("PFCP Session Modification from bearer: "
+            "bearer_id=%d sess_id=%d gtp_xact_id=%d flags=0x%llx",
+            bearer->id, sess->id, gtp_xact_id, (unsigned long long)flags);
 
     xact = ogs_pfcp_xact_local_create(
             sess->pfcp_node, bearer_timeout, OGS_UINT_TO_POINTER(bearer->id));
